@@ -1,27 +1,15 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
- * License as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * Authors:
- *    Fabiano Fidêncio <fidencio@redhat.com>
- *    Philip Withnall <philip@tecnocode.co.uk>
- *    Vadim Rutkovsky <vrutkovs@redhat.com>
+ * SPDX-FileCopyrightText: (C) 2013 Red Hat, Inc. (www.redhat.com)
+ * SPDX-FileContributor: Fabiano Fidêncio <fidencio@redhat.com>
+ * SPDX-FileContributor: Philip Withnall <philip@tecnocode.co.uk>
+ * SPDX-FileContributor: Vadim Rutkovsky <vrutkovs@redhat.com>
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#include "server/e-ews-connection.h"
-#include "server/e-ews-debug.h"
-#include "server/e-ews-folder.h"
+#include "common/e-ews-connection.h"
+#include "common/e-ews-debug.h"
+#include "common/e-ews-folder.h"
 
 #include "ews-test-common.h"
 
